Stan Math Library: stan/math/prim/mat/fun/common_type.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
common_type.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <boost/math/tools/promotion.hpp>`
`#include <vector>`

Go to the source code of this file.

## Classes
struct | stan::math::common_type< T1, T2 >
struct | stan::math::common_type< std::vector< T1 >, std::vector< T2 > >
struct | stan::math::common_type< Eigen::Matrix< T1, R, C >, Eigen::Matrix< T2, R, C > >

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.